# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Type.pm 66683 2008-07-24T05:52:58.814530Z daisuke  $

package Google::Chart::Type;
use Moose::Role;

with 'Google::Chart::QueryComponent';

no Moose;

1;

__END__

=head1 NAME

Google::Chart::Type - Google::Chart Type Role

=cut
